==> haskell-text-short-0.1.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-short.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-short
version: 0.1.2
id: text-short-0.1.2-LDEC6SHL7hqIvBv065JaNA
key: text-short-0.1.2-LDEC6SHL7hqIvBv065JaNA
license: BSD3
maintainer: hvr@gnu.org
synopsis: Memory-efficient representation of Unicode text strings
description:
    This package provides the '\''ShortText'\'' type which is suitable for keeping many short strings in memory. This is similiar to how '\''ShortByteString'\'' relates to '\''ByteString'\''.
    .
    The main difference between '\''Text'\'' and '\''ShortText'\'' is that '\''ShortText'\'' uses UTF-8 instead of UTF-16 internally and also doesn'\''t support zero-copy slicing (thereby saving 2 words). Consequently, the memory footprint of a (boxed) '\''ShortText'\'' value is 4 words (2 words when unboxed) plus the length of the UTF-8 encoded payload.
category: Data
author: Herbert Valerio Riedel
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Short Data.Text.Short.Partial Data.Text.Short.Unsafe
hidden-modules: Data.Text.Short.Internal PrimOps
abi: c60749f05f7c58017a6015a8a9263b43
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/text-short-0.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/text-short-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/text-short-0.1.2
hs-libraries: HStext-short-0.1.2-LDEC6SHL7hqIvBv065JaNA
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan deepseq-1.4.3.0
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz binary-0.8.5.1 ghc-prim-0.5.1.1
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
haddock-interfaces: /usr/share/doc/haskell-text-short/html/text-short.haddock
haddock-html: /usr/share/doc/haskell-text-short/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-short-0.1.2-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-short.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-short
version: 0.1.2
id: text-short-0.1.2-HUS6IYWvnucBN2v2juXpOJ
key: text-short-0.1.2-HUS6IYWvnucBN2v2juXpOJ
license: BSD3
maintainer: hvr@gnu.org
synopsis: Memory-efficient representation of Unicode text strings
description:
    This package provides the '\''ShortText'\'' type which is suitable for keeping many short strings in memory. This is similiar to how '\''ShortByteString'\'' relates to '\''ByteString'\''.
    .
    The main difference between '\''Text'\'' and '\''ShortText'\'' is that '\''ShortText'\'' uses UTF-8 instead of UTF-16 internally and also doesn'\''t support zero-copy slicing (thereby saving 2 words). Consequently, the memory footprint of a (boxed) '\''ShortText'\'' value is 4 words (2 words when unboxed) plus the length of the UTF-8 encoded payload.
category: Data
author: Herbert Valerio Riedel
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Short Data.Text.Short.Partial Data.Text.Short.Unsafe
hidden-modules: Data.Text.Short.Internal PrimOps
abi: 0d67cd23441c637ece19432369165323
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/text-short-0.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/text-short-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/text-short-0.1.2
hs-libraries: HStext-short-0.1.2-HUS6IYWvnucBN2v2juXpOJ
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan deepseq-1.4.3.0
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz binary-0.8.5.1 ghc-prim-0.5.1.1
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
haddock-interfaces: /usr/share/doc/haskell-text-short/html/text-short.haddock
haddock-html: /usr/share/doc/haskell-text-short/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
